@@ -1,4 +1,4 @@
-//! Peripheral access API for STM32F0 microcontrollers
+//! Peripheral access API for STM32F1 microcontrollers
 //! (generated using [svd2rust](https://github.com/rust-embedded/svd2rust)
 //! 0.19.0)
 //!
@@ -8,9 +8,9 @@
 //! For more details see the README here:
 //! [stm32-rs](https://github.com/stm32-rs/stm32-rs)
 //!
-//! This crate supports all STM32F0 devices; for the complete list please
+//! This crate supports all STM32F1 devices; for the complete list please
 //! see:
-//! [stm32f0](https://crates.io/crates/stm32f0)
+//! [stm32f1](https://crates.io/crates/stm32f1)
 //!
 //! Due to doc build limitations, not all devices may be shown on docs.rs;
 //! a representative few have been selected instead. For a complete list of
@@ -23,15 +23,18 @@
 mod generic;
 pub use self::generic::*;
 
-#[cfg(feature = "stm32f0x0")]
-pub mod stm32f0x0;
+#[cfg(feature = "stm32f100")]
+pub mod stm32f100;
 
-#[cfg(feature = "stm32f0x1")]
-pub mod stm32f0x1;
+#[cfg(feature = "stm32f101")]
+pub mod stm32f101;
 
-#[cfg(feature = "stm32f0x2")]
-pub mod stm32f0x2;
+#[cfg(feature = "stm32f102")]
+pub mod stm32f102;
 
-#[cfg(feature = "stm32f0x8")]
-pub mod stm32f0x8;
+#[cfg(feature = "stm32f103")]
+pub mod stm32f103;
+
+#[cfg(feature = "stm32f107")]
+pub mod stm32f107;
 
